@@ -18,11 +18,13 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  ***********************************************************************/
 
-#ifndef CODEINE_ROOTDBUSHANDLER_H
-#define CODEINE_ROOTDBUSHANDLER_H
+#ifndef DRAGONPLAYER_ROOTDBUSHANDLER_H
+#define DRAGONPLAYER_ROOTDBUSHANDLER_H
 
 #include <QObject>
 
+#include "mpristypes.h"
+
 class RootDbusHandler : public QObject
 {
     Q_OBJECT
@@ -32,7 +34,7 @@ public:
 
     QString Identity();
     void Quit();
-    float MprisVersion();
+    Mpris::Version MprisVersion();
 };
 
 #endif
