@@ -1,6 +1,8 @@
 /***************************************************************************
     copyright            : (C) 2004 by Scott Wheeler
     email                : wheeler@kde.org
+    copyright            : (c) 2007 by Michael Pyne
+    email                : michael.pyne@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -15,34 +17,46 @@
  *                                                                         *
  *   You should have received a copy of the GNU Lesser General Public      *
  *   License along with this library; if not, write to the Free Software   *
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  *
- *   USA                                                                   *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301, USA                                                       *
  ***************************************************************************/
 
 #include "ktrm.h"
+#include <config-juk.h>
 
-#if HAVE_MUSICBRAINZ
+#ifdef HAVE_TUNEPIMP //Silence warning about HAVE_TUNEPIMP not being defined.
+#if HAVE_TUNEPIMP
 
-#include <kapplication.h>
-#include <kresolver.h>
+#include <k3resolver.h>
 #include <kprotocolmanager.h>
 #include <kurl.h>
 #include <kdebug.h>
+#include <kio/job.h>
 
-#include <qmutex.h>
-#include <qregexp.h>
-#include <qevent.h>
-#include <qobject.h>
-#include <qfile.h>
+#include <QCoreApplication>
+#include <QtAlgorithms>
+#include <QMutex>
+#include <QRegExp>
+#include <QFile>
+#include <QEvent>
+#include <QDomDocument>
 
+#if HAVE_TUNEPIMP >= 5
+#include <tunepimp-0.5/tp_c.h>
+#else
 #include <tunepimp/tp_c.h>
+#endif
+#ifdef Q_WS_X11
 #include <fixx11h.h>
+#endif
+
+#include "ktrm.moc"
 
 class KTRMLookup;
 
 extern "C"
 {
-#if HAVE_MUSICBRAINZ >= 4
+#if HAVE_TUNEPIMP >= 4
     static void TRMNotifyCallback(tunepimp_t pimp, void *data, TPCallbackEnum type, int fileId, TPFileStatus status);
 #else
     static void TRMNotifyCallback(tunepimp_t pimp, void *data, TPCallbackEnum type, int fileId);
@@ -70,7 +84,7 @@ public:
         int id;
 
         if(!m_fileMap.contains(lookup->file())) {
-#if HAVE_MUSICBRAINZ >= 4
+#if HAVE_TUNEPIMP >= 4
             id = tp_AddFile(m_pimp, QFile::encodeName(lookup->file()), 0);
 #else
             id = tp_AddFile(m_pimp, QFile::encodeName(lookup->file()));
@@ -125,24 +139,27 @@ protected:
     {
         m_pimp = tp_New("KTRM", "0.1");
         //tp_SetDebug(m_pimp, true);
+#if HAVE_TUNEPIMP < 5
         tp_SetTRMCollisionThreshold(m_pimp, 100);
+        tp_SetAutoFileLookup(m_pimp,true);
+#endif        
         tp_SetAutoSaveThreshold(m_pimp, -1);
         tp_SetMoveFiles(m_pimp, false);
         tp_SetRenameFiles(m_pimp, false);
-#if HAVE_MUSICBRAINZ >= 4
+#if HAVE_TUNEPIMP >= 4
         tp_SetFileNameEncoding(m_pimp, "UTF-8");
 #else
         tp_SetUseUTF8(m_pimp, true);
 #endif
         tp_SetNotifyCallback(m_pimp, TRMNotifyCallback, 0);
-
+#if HAVE_TUNEPIMP < 5
         // Re-read proxy config.
         KProtocolManager::reparseConfiguration();
 
         if(KProtocolManager::useProxy()) {
             // split code copied from kcm_kio.
             QString noProxiesFor = KProtocolManager::noProxyFor();
-            QStringList noProxies = QStringList::split(QRegExp("[',''\t'' ']"), noProxiesFor);
+            QStringList noProxies = noProxiesFor.split(QRegExp("[',''\t'' ']"), QString::SkipEmptyParts);
             bool useProxy = true;
 
             // Host that libtunepimp will contact.
@@ -150,12 +167,12 @@ protected:
             QString tunepimpHostWithPort = "www.musicbrainz.org:80";
 
             // Check what hosts are allowed to proceed without being proxied,
-            // or is using reversed proxy, what hosts must be proxied.
-            for(QStringList::ConstIterator it = noProxies.constBegin(); it != noProxies.constEnd(); ++it) {
-                QString normalizedHost = KNetwork::KResolver::normalizeDomain(*it);
+            // or if using reversed proxy, what hosts must be proxied.
+            foreach(const QString &host, noProxies) {
+                QString normalizedHost = KNetwork::KResolver::normalizeDomain(host);
 
                 if(normalizedHost == tunepimpHost ||
-                   tunepimpHost.endsWith("." + normalizedHost))
+                   tunepimpHost.endsWith('.' + normalizedHost))
                 {
                     useProxy = false;
                     break;
@@ -164,7 +181,7 @@ protected:
                 // KDE's proxy mechanism also supports exempting a specific
                 // host/port combo, check that also.
                 if(normalizedHost == tunepimpHostWithPort ||
-                   tunepimpHostWithPort.endsWith("." + normalizedHost))
+                   tunepimpHostWithPort.endsWith('.' + normalizedHost))
                 {
                     useProxy = false;
                     break;
@@ -176,13 +193,16 @@ protected:
                 useProxy = !useProxy;
 
             if(useProxy) {
-                KURL proxy = KProtocolManager::proxyFor("http");
+                KUrl proxy = KProtocolManager::proxyFor("http");
                 QString proxyHost = proxy.host();
 
-                kdDebug(65432) << "Using proxy server " << proxyHost << " for www.musicbrainz.org.\n";
-                tp_SetProxy(m_pimp, proxyHost.latin1(), short(proxy.port()));
+                kDebug() << "Using proxy server " << proxyHost << " for www.musicbrainz.org.\n";
+                tp_SetProxy(m_pimp, proxyHost.toAscii(), short(proxy.port()));
             }
         }
+#else
+        tp_SetMusicDNSClientId(m_pimp, "0c6019606b1d8a54d0985e448f3603ca");
+#endif
     }
 
     ~KTRMRequestHandler()
@@ -202,20 +222,23 @@ private:
  * A custom event type used for signalling that a TRM lookup is finished.
  */
 
-class KTRMEvent : public QCustomEvent
+class KTRMEvent : public QEvent
 {
 public:
     enum Status {
         Recognized,
         Unrecognized,
         Collision,
+        PuidGenerated,
         Error
     };
 
     KTRMEvent(int fileId, Status status) :
-        QCustomEvent(id),
+        QEvent(static_cast<QEvent::Type>(id)),
         m_fileId(fileId),
-        m_status(status) {}
+        m_status(status)
+    {
+    }
 
     int fileId() const
     {
@@ -244,7 +267,7 @@ class KTRMEventHandler : public QObject
 public:
     static void send(int fileId, KTRMEvent::Status status)
     {
-        KApplication::postEvent(instance(), new KTRMEvent(fileId, status));
+        QCoreApplication::postEvent(instance(), new KTRMEvent(fileId, status));
     }
 
 protected:
@@ -259,7 +282,7 @@ protected:
         return &handler;
     }
 
-    virtual void customEvent(QCustomEvent *event)
+    virtual void customEvent(QEvent *event)
     {
         if(!event->type() == KTRMEvent::id)
             return;
@@ -275,7 +298,7 @@ protected:
         }
 
         KTRMLookup *lookup = KTRMRequestHandler::instance()->lookup(e->fileId());
-#if HAVE_MUSICBRAINZ >= 4
+#if HAVE_TUNEPIMP >= 4
         if ( e->status() != KTRMEvent::Unrecognized)
 #endif
             KTRMRequestHandler::instance()->removeFromLookupMap(e->fileId());
@@ -295,15 +318,17 @@ protected:
         case KTRMEvent::Error:
             lookup->error();
             break;
+        case KTRMEvent::PuidGenerated:
+            break; // XXX: Does anything special need done here?
         }
     }
 };
 
 /**
- * Callback fuction for TunePimp lookup events.
+ * Callback function for TunePimp lookup events.
  */
-#if HAVE_MUSICBRAINZ >= 4
-static void TRMNotifyCallback(tunepimp_t /*pimp*/, void* /*data*/, TPCallbackEnum type, int fileId, TPFileStatus status)
+#if HAVE_TUNEPIMP >= 4
+static void TRMNotifyCallback(tunepimp_t /*pimp*/, void * /*data*/, TPCallbackEnum type, int fileId, TPFileStatus status)
 #else
 static void TRMNotifyCallback(tunepimp_t pimp, void *data, TPCallbackEnum type, int fileId)
 #endif
@@ -311,7 +336,7 @@ static void TRMNotifyCallback(tunepimp_t pimp, void *data, TPCallbackEnum type,
     if(type != tpFileChanged)
         return;
 
-#if HAVE_MUSICBRAINZ < 4
+#if HAVE_TUNEPIMP < 4
     track_t track = tp_GetTrack(pimp, fileId);
     TPFileStatus status = tr_GetStatus(track);
 #endif
@@ -323,19 +348,27 @@ static void TRMNotifyCallback(tunepimp_t pimp, void *data, TPCallbackEnum type,
     case eUnrecognized:
         KTRMEventHandler::send(fileId, KTRMEvent::Unrecognized);
         break;
+#if HAVE_TUNEPIMP >= 5
+    case ePUIDLookup:
+    case ePUIDCollision:
+    case eFileLookup:
+        KTRMEventHandler::send(fileId, KTRMEvent::PuidGenerated);
+        break;
+#else
     case eTRMCollision:
-#if HAVE_MUSICBRAINZ >= 4
+#if HAVE_TUNEPIMP >= 4
     case eUserSelection:
 #endif
         KTRMEventHandler::send(fileId, KTRMEvent::Collision);
         break;
+#endif
     case eError:
         KTRMEventHandler::send(fileId, KTRMEvent::Error);
         break;
     default:
         break;
     }
-#if HAVE_MUSICBRAINZ < 4
+#if HAVE_TUNEPIMP < 4
     tp_ReleaseTrack(pimp, track);
 #endif
 }
@@ -461,7 +494,7 @@ int KTRMLookup::fileId() const
 
 void KTRMLookup::recognized()
 {
-    kdDebug() << k_funcinfo << d->file << endl;
+    kDebug() << d->file;
 
     d->results.clear();
 
@@ -487,14 +520,19 @@ void KTRMLookup::recognized()
 
 void KTRMLookup::unrecognized()
 {
-    kdDebug() << k_funcinfo << d->file << endl;
-#if HAVE_MUSICBRAINZ >= 4
+    kDebug() << d->file;
+#if HAVE_TUNEPIMP >= 4
     char trm[255];
     bool finish = false;
     trm[0] = 0;
     track_t track = tp_GetTrack(KTRMRequestHandler::instance()->tunePimp(), d->fileId);
     tr_Lock(track);
+#if HAVE_TUNEPIMP >= 5
+    tr_GetPUID(track, trm, 255);
+#else
     tr_GetTRM(track, trm, 255);
+#endif
+
     if ( !trm[0] ) {
         tr_SetStatus(track, ePending);
         tp_Wake(KTRMRequestHandler::instance()->tunePimp(), track);
@@ -512,12 +550,13 @@ void KTRMLookup::unrecognized()
 
 void KTRMLookup::collision()
 {
-    kdDebug() << k_funcinfo << d->file << endl;
+#if HAVE_TUNEPIMP && HAVE_TUNEPIMP < 5
+    kDebug() << d->file;
 
     track_t track = tp_GetTrack(KTRMRequestHandler::instance()->tunePimp(), d->fileId);
 
     if(track <= 0) {
-        kdDebug() << "invalid track number" << endl;
+        kDebug() << "invalid track number";
         return;
     }
 
@@ -531,17 +570,17 @@ void KTRMLookup::collision()
 
         switch(type) {
         case eNone:
-            kdDebug() << k_funcinfo << "eNone" << endl;
+            kDebug() << "eNone";
             break;
         case eArtistList:
-            kdDebug() << "eArtistList" << endl;
+            kDebug() << "eArtistList";
             break;
         case eAlbumList:
-            kdDebug() << "eAlbumList" << endl;
+            kDebug() << "eAlbumList";
             break;
         case eTrackList:
         {
-            kdDebug() << "eTrackList" << endl;
+            kDebug() << "eTrackList";
             albumtrackresult_t **tracks = (albumtrackresult_t **) results;
             d->results.clear();
 
@@ -549,11 +588,11 @@ void KTRMLookup::collision()
                 KTRMResult result;
 
                 result.d->title = QString::fromUtf8(tracks[i]->name);
-#if HAVE_MUSICBRAINZ >= 4
+#if HAVE_TUNEPIMP >= 4
                 result.d->artist = QString::fromUtf8(tracks[i]->artist.name);
                 result.d->album = QString::fromUtf8(tracks[i]->album.name);
                 result.d->year = tracks[i]->album.releaseYear;
-#else 
+#else
                 result.d->artist = QString::fromUtf8(tracks[i]->artist->name);
                 result.d->album = QString::fromUtf8(tracks[i]->album->name);
                 result.d->year = tracks[i]->album->releaseYear;
@@ -566,7 +605,7 @@ void KTRMLookup::collision()
             break;
         }
         case eMatchedTrack:
-            kdDebug() << k_funcinfo << "eMatchedTrack" << endl;
+            kDebug() << "eMatchedTrack";
             break;
         }
 
@@ -576,11 +615,92 @@ void KTRMLookup::collision()
     tr_Unlock(track);
 
     finished();
+#endif
 }
 
+void KTRMLookup::puidGenerated()
+{
+#if HAVE_TUNEPIMP >= 5
+    char puid[255] = {0};
+    track_t track = tp_GetTrack(KTRMRequestHandler::instance()->tunePimp(), d->fileId);
+    tr_Lock(track);
+
+    tr_GetPUID(track, puid, 255);
+    tr_Unlock(track);
+    tp_ReleaseTrack(KTRMRequestHandler::instance()->tunePimp(), track);
+    d->results.clear();
+
+    KIO::Job *job = KIO::storedGet( QString( "http://musicbrainz.org/ws/1/track/?type=xml&puid=%1" ).arg( puid ) , KIO::NoReload, KIO::HideProgressInfo );
+    connect( job, SIGNAL( result( KJob* ) ), SLOT( lookupResult( KJob* ) ) );
+#endif
+}
+
+void KTRMLookup::lookupResult( KJob* job )
+{
+#if HAVE_TUNEPIMP >= 5
+    if ( !job->error() == 0 ) {
+        finished();
+        return;
+    }
+    KIO::StoredTransferJob* const storedJob = static_cast<KIO::StoredTransferJob*>( job );
+    QString xml = QString::fromUtf8( storedJob->data().data(), storedJob->data().size() );
+
+    QDomDocument doc;
+    QDomElement e;
+
+    if( !doc.setContent( xml ) ) {
+        finished();
+        return;
+    }
+
+    e = doc.namedItem( "metadata" ).toElement().namedItem( "track-list" ).toElement();
+
+    QStringList strList = d->file.split('/');
+
+    QDomNode n = e.namedItem("track");
+    for( ; !n.isNull();  n = n.nextSibling() ) {
+        QDomElement track = n.toElement();
+        KTRMResult result;
+
+        result.d->title = track.namedItem( "title" ).toElement().text();
+        result.d->artist = track.namedItem( "artist" ).toElement().namedItem( "name" ).toElement().text();
+        QDomNode releaseNode = track.namedItem("release-list").toElement().namedItem("release");
+        for( ; !releaseNode.isNull();  releaseNode = releaseNode.nextSibling() ) {
+            KTRMResult tmpResult( result );
+            QDomElement release = releaseNode.toElement();
+
+            tmpResult.d->album = release.namedItem( "title" ).toElement().text();
+            QDomNode tracklistN = release.namedItem( "track-list" );
+            if ( !tracklistN.isNull() ) {
+                QDomElement tracklist = tracklistN.toElement();
+                if ( !tracklist.attribute( "offset" ).isEmpty() )
+                    tmpResult.d->track = tracklist.attribute( "offset" ).toInt() + 1;
+            }
+            //tmpResult.d->year = ???;
+            tmpResult.d->relevance = static_cast<int>(
+                4 * stringSimilarity(strList,tmpResult.d->title) +
+                2 * stringSimilarity(strList,tmpResult.d->artist) +
+                1 * stringSimilarity(strList,tmpResult.d->album)
+                );
+/*
+            if( !d->results.contains( tmpResult ) )
+                d->results.append( tmpResult );
+                */
+        }
+     }
+
+     qSort(d->results);
+
+     finished();
+#else
+    Q_UNUSED( job );
+#endif
+}
+
+
 void KTRMLookup::error()
 {
-    kdDebug() << k_funcinfo << d->file << endl;
+    kDebug() << d->file;
 
     d->results.clear();
     finished();
@@ -601,6 +721,56 @@ void KTRMLookup::finished()
         delete this;
 }
 
+////////////////////////////////////////////////////////////////////////////////
+// Helper Functions used for sorting MusicBrainz results
+////////////////////////////////////////////////////////////////////////////////
+
+double stringSimilarity(const QStringList &l, const QString &s)
+{
+    double max = 0, current = 0;
+
+    foreach(const QString &string, l) {
+        if(max < (current = stringSimilarity(string, s)))
+            max = current;
+    }
+
+    return max;
+}
+
+double stringSimilarity(QString s1, QString s2)
+{
+    QRegExp whiteSpace("[\\s\\t\\r\\n]");
+
+    s1.remove(whiteSpace);
+    s2.remove(whiteSpace);
+
+    double nCommon = 0;
+    int p1 = 0, p2 = 0, x1 = 0, x2 = 0;
+    int l1 = s1.length(), l2 = s2.length(), l3 = l1 + l2;
+    QChar c1 = 0, c2 = 0;
+
+    while(p1 < l1 && p2 < l2) {
+        c1 = s1.at(p1); c2 = s2.at(p2);
+
+        if(c1.toUpper() == c2.toUpper()) {
+            ++nCommon;
+            ++p1; ++p2;
+        }
+        else {
+            x1 = s1.indexOf(c2, p1, Qt::CaseInsensitive);
+            x2 = s2.indexOf(c1, p2, Qt::CaseInsensitive);
+
+            if( (x1 == x2 || -1 == x1) || (-1 != x2 && x1 > x2) )
+                ++p2;
+            else
+                ++p1;
+        }
+    }
+
+    return l3 ? nCommon * 2.0 / l3 : 1.0;
+}
+
+#endif
 #endif
 
-// vim: set et ts=8 sw=4:
+// vim: set et sw=4 tw=0 sta:
