@@ -13,17 +13,21 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "statuslabel.h"
+
 #include <kaction.h>
 #include <kpushbutton.h>
 #include <kiconloader.h>
-#include <ksqueezedtextlabel.h> 
+#include <ksqueezedtextlabel.h>
 #include <klocale.h>
 #include <kdebug.h>
 
-#include <qtooltip.h>
-#include <qlayout.h>
+#include <QMouseEvent>
+#include <QLabel>
+#include <QFrame>
+#include <QHBoxLayout>
+#include <QEvent>
 
-#include "statuslabel.h"
 #include "filehandle.h"
 #include "playlistinterface.h"
 #include "actioncollection.h"
@@ -35,8 +39,8 @@ using namespace ActionCollection;
 // public methods
 ////////////////////////////////////////////////////////////////////////////////
 
-StatusLabel::StatusLabel(PlaylistInterface *playlist, QWidget *parent, const char *name) :
-    QHBox(parent, name),
+StatusLabel::StatusLabel(PlaylistInterface *playlist, QWidget *parent) :
+    KHBox(parent),
     PlaylistObserver(playlist),
     m_showTimeRemaining(false)
 {
@@ -46,28 +50,29 @@ StatusLabel::StatusLabel(PlaylistInterface *playlist, QWidget *parent, const cha
 
     // Make sure that we have enough of a margin to suffice for the borders,
     // hence the "lineWidth() * 2"
-    QHBoxLayout *trackAndPlaylistLayout = new QHBoxLayout(trackAndPlaylist,
-                                                          trackAndPlaylist->lineWidth() * 2,
-                                                          5, "trackAndPlaylistLayout");
+    QHBoxLayout *trackAndPlaylistLayout = new QHBoxLayout( trackAndPlaylist );
+    trackAndPlaylistLayout->setMargin( trackAndPlaylist->lineWidth() * 2 );
+    trackAndPlaylistLayout->setSpacing( 5 );
+    trackAndPlaylistLayout->setObjectName( "trackAndPlaylistLayout");
     trackAndPlaylistLayout->addSpacing(5);
 
-    m_playlistLabel = new KSqueezedTextLabel(trackAndPlaylist, "playlistLabel");
+    m_playlistLabel = new KSqueezedTextLabel(trackAndPlaylist);
     trackAndPlaylistLayout->addWidget(m_playlistLabel);
     m_playlistLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    m_playlistLabel->setTextFormat(PlainText);
-    m_playlistLabel->setAlignment(AlignLeft | AlignVCenter);
+    m_playlistLabel->setTextFormat(Qt::PlainText);
+    m_playlistLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
 
-    m_trackLabel = new KSqueezedTextLabel(trackAndPlaylist, "trackLabel");
+    m_trackLabel = new KSqueezedTextLabel(trackAndPlaylist);
     trackAndPlaylistLayout->addWidget(m_trackLabel);
-    m_trackLabel->setAlignment(AlignRight | AlignVCenter);
+    m_trackLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
     m_trackLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    m_trackLabel->setTextFormat(PlainText);
+    m_trackLabel->setTextFormat(Qt::PlainText);
 
     trackAndPlaylistLayout->addSpacing(5);
 
     m_itemTimeLabel = new QLabel(this);
     QFontMetrics fontMetrics(font());
-    m_itemTimeLabel->setAlignment(AlignCenter);
+    m_itemTimeLabel->setAlignment(Qt::AlignCenter);
     m_itemTimeLabel->setMinimumWidth(fontMetrics.boundingRect("000:00 / 000:00").width());
     m_itemTimeLabel->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
     m_itemTimeLabel->setFrameStyle(Box | Sunken);
@@ -76,16 +81,16 @@ StatusLabel::StatusLabel(PlaylistInterface *playlist, QWidget *parent, const cha
     setItemTotalTime(0);
     setItemCurrentTime(0);
 
-    QHBox *jumpBox = new QHBox(this);
+    KHBox *jumpBox = new KHBox(this);
     jumpBox->setFrameStyle(Box | Sunken);
     jumpBox->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Minimum);
 
     QPushButton *jumpButton = new QPushButton(jumpBox);
-    jumpButton->setPixmap(SmallIcon("up"));
+    jumpButton->setIcon(SmallIcon("go-up"));
     jumpButton->setFlat(true);
 
-    QToolTip::add(jumpButton, i18n("Jump to the currently playing item"));
-    connect(jumpButton, SIGNAL(clicked()), action("showPlaying"), SLOT(activate()));
+    jumpButton->setToolTip( i18n("Jump to the currently playing item"));
+    connect(jumpButton, SIGNAL(clicked()), action("showPlaying"), SLOT(trigger()));
 
     installEventFilter(this);
 
@@ -103,12 +108,12 @@ void StatusLabel::updateCurrent()
         FileHandle file = playlist()->currentFile();
 
         QString mid =  file.tag()->artist().isEmpty() || file.tag()->title().isEmpty()
-            ? QString::null : QString(" - ");
+            ? QString::null : QString(" - ");	//krazy:exclude=nullstrassign for old broken gcc
 
         QString text = file.tag()->artist() + mid + file.tag()->title();
 
         m_trackLabel->setText(text);
-        m_playlistLabel->setText(playlist()->name().simplifyWhiteSpace());
+        m_playlistLabel->setText(playlist()->name().simplified());
     }
 }
 
@@ -130,7 +135,7 @@ void StatusLabel::updateData()
         QString timeString;
 
         if(days > 0) {
-            timeString = i18n("1 day", "%n days", days);
+            timeString = i18np("1 day", "%1 days", days);
             timeString.append(" ");
         }
 
@@ -140,7 +145,7 @@ void StatusLabel::updateData()
             timeString.append(QString().sprintf("%1d:%02d", minutes, seconds));
 
         m_playlistLabel->setText(playlist()->name());
-        m_trackLabel->setText(i18n("1 item", "%n items", playlist()->count()) + " - " + timeString);
+        m_trackLabel->setText(i18np("1 item", "%1 items", playlist()->count()) + " - " + timeString);
     }
 }
 
@@ -177,14 +182,14 @@ bool StatusLabel::eventFilter(QObject *o, QEvent *e)
 
     QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(e);
     if(e->type() == QEvent::MouseButtonRelease &&
-       mouseEvent->button() == LeftButton)
+       mouseEvent->button() == Qt::LeftButton)
     {
         if(o == m_itemTimeLabel) {
             m_showTimeRemaining = !m_showTimeRemaining;
             updateTime();
         }
         else
-            action("showPlaying")->activate();
+            action("showPlaying")->trigger();
 
         return true;
     }
@@ -195,11 +200,13 @@ QString StatusLabel::formatTime(int minutes, int seconds) // static
 {
     QString m = QString::number(minutes);
     if(m.length() == 1)
-        m = "0" + m;
+        m = '0' + m;
     QString s = QString::number(seconds);
     if(s.length() == 1)
-        s = "0" + s;
-    return m + ":" + s;
+        s = '0' + s;
+    return m + ':' + s;
 }
 
 #include "statuslabel.moc"
+
+// vim: set et sw=4 tw=0 sta:
