@@ -5,8 +5,8 @@
     copyright            : (C) 2002 - 2004 by Scott Wheeler
     email                : wheeler@kde.org
 
-    copyright            : (C) 2007, 2008 by Michael Pyne
-    email                : michael.pyne@kdemail.net
+    copyright            : (C) 2007, 2008, 2009 by Michael Pyne
+    email                : mpyne@kde.org
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,10 +18,10 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef SYSTEMTRAY_H
-#define SYSTEMTRAY_H
+#ifndef JUK_SYSTEMTRAY_H
+#define JUK_SYSTEMTRAY_H
 
-#include <ksystemtrayicon.h>
+#include <kstatusnotifieritem.h>
 
 #include <QVector>
 #include <QColor>
@@ -29,8 +29,7 @@
 #include <QIcon>
 #include <QFrame>
 
-class QMouseEvent;
-class QWheelEvent;
+class SystemTray;
 class PlayerManager;
 class QLabel;
 class QTimer;
@@ -42,13 +41,13 @@ class QVBoxLayout;
  * Workalike of KPassivePopup intended to more easily support JuK's particular
  * usage pattern, including things like staying open while under the mouse.
  *
- * @author Michael Pyne <michael.pyne@kdemail.net>
+ * @author Michael Pyne <mpyne@kde.org>
  */
 class PassiveInfo : public QFrame
 {
     Q_OBJECT
 public:
-    PassiveInfo(QSystemTrayIcon *parent = 0);
+    PassiveInfo(SystemTray *parent = 0);
 
     // Sets view as a child widget to show in the popup window.
     // This widget does not take ownership of the widget.  If you want it auto-deleted,
@@ -73,27 +72,26 @@ protected:
     virtual void hideEvent(QHideEvent *);
 
 private:
-    // Move us near the system tray icon.
+    // Move us near the required position.
     void positionSelf();
 
 private slots:
     void timerExpired();
 
 private:
-    QSystemTrayIcon *m_icon;
+    SystemTray *m_icon;
     QTimer *m_timer;
     QVBoxLayout *m_layout;
     QWidget *m_view;
     bool m_justDie;
 };
 
-class SystemTray : public KSystemTrayIcon
+class SystemTray : public KStatusNotifierItem
 {
     Q_OBJECT
 
 public:
     SystemTray(PlayerManager *player, QWidget *parent = 0);
-    virtual ~SystemTray();
 
 signals:
     // Emitted when the fade process is complete.
@@ -102,21 +100,14 @@ signals:
 private:
     static const int STEPS = 20; ///< Number of intermediate steps for fading.
 
-    virtual void wheelEvent(QWheelEvent *e);
     void createPopup();
     void setToolTip(const QString &tip = QString(), const QPixmap &cover = QPixmap());
-    void ousePressEvent(QMouseEvent *e);
-    QPixmap createPixmap(const QString &pixName);
-
-    // Returns true if the popup will need to have its buttons on the left
-    // (because the JuK icon is on the left side of the screen.
-    bool buttonsToLeft() const;
 
     void createButtonBox(QWidget *parent);
 
     // Creates the widget layout for the popup, returning the QVBox that
-    // holds the text labels.  Uses buttonsToLeft() to figure out which
-    // order to create them in.  @p file is used to grab the cover.
+    // holds the text labels.
+
     KVBox *createPopupLayout(QWidget *parent, const FileHandle &file);
 
     void addSeparatorLine(QWidget *parent);
@@ -125,12 +116,13 @@ private:
     // Interpolates from start color to end color.  If @p step == 0, then
     // m_startColor is returned, while @p step == @steps returns
     // m_endColor.
+
     QColor interpolateColor(int step, int steps = STEPS);
 
 private slots:
     void slotPlay();
     void slotTogglePopup();
-    void slotPause() { setIcon(m_pausePix); }
+    void slotPause();
     void slotStop();
     void slotPopupDestroyed();
     void slotNextStep(); ///< This is the fading routine.
@@ -139,15 +131,11 @@ private slots:
     void slotBack();
     void slotFadeOut(); ///< Fades out the text
     void slotMouseInPopup(); ///< Forces the text back to its normal color.
-    void slotActivated(QSystemTrayIcon::ActivationReason reason);
+    void scrollEvent(int delta, Qt::Orientation orientation);
 
 private:
-    QPixmap m_playPix;
-    QPixmap m_pausePix;
-    QPixmap m_currentPix;
     QPixmap m_backPix;
     QPixmap m_forwardPix;
-    QIcon   m_appPix;
     QColor m_startColor, m_endColor;
 
     PassiveInfo *m_popup;
@@ -161,6 +149,6 @@ private:
     bool m_hasCompositionManager;
 };
 
-#endif // SYSTEMTRAY_H
+#endif // JUK_SYSTEMTRAY_H
 
 // vim: set et sw=4 tw=0 sta:
