@@ -53,7 +53,7 @@
 #include "viewdockareapopup.h"
 
 KMixDockWidget::KMixDockWidget(KMixWindow* parent, QWidget *referenceWidget, bool volumePopup)
-    : KNotificationItem(parent)
+    : KStatusNotifierItem(parent)
     , _referenceWidget(referenceWidget)
     , _audioPlayer(0L)
     , _playBeepOnVolumeChange(false) // disabled due to triggering a "Bug"
@@ -94,8 +94,7 @@ void KMixDockWidget::createActions()
     KToggleAction *action = actionCollection()->add<KToggleAction>( "dock_mute" );
     action->setText( i18n( "M&ute" ) );
     connect(action, SIGNAL(triggered(bool) ), SLOT( dockMute() ));
-    QAction *a = actionCollection()->action( "dock_mute" );
-    if ( a ) menu->addAction( a );
+    menu->addAction( action );
 }
 
   // Put "Select Master Channel" dialog in context menu
@@ -103,8 +102,7 @@ void KMixDockWidget::createActions()
   QAction *action = actionCollection()->addAction( "select_master" );
   action->setText( i18n("Select Master Channel...") );
   connect(action, SIGNAL(triggered(bool) ), SLOT(selectMaster()));
-  QAction *a2 = actionCollection()->action( "select_master" );
-  if (a2) menu->addAction( a2 );
+  menu->addAction( action );
   }
 
    // Setup volume preview
@@ -271,13 +269,15 @@ KMixDockWidget::updatePixmap()
 
 void KMixDockWidget::activate(const QPoint &pos)
 {
-   // Make sure this will work
-   // It is a KMenu now, and this check is a bit weird,
-   // i believe this should not rely on parent()
    KMenu* dockAreaPopup = qobject_cast<KMenu*>(_referenceWidget);
-   const bool activated = (dockAreaPopup && !dockAreaPopup->isVisible());
-   if ( !dockAreaPopup || !activated ) {
-      // If the associated parent os the MainWindow (and not the ViewDockAreaPopup), we return.
+   if ( !dockAreaPopup ) {
+      // Use default KStatusNotifierItem behavior if we are not using the
+      // dockAreaPopup
+      KStatusNotifierItem::activate(pos);
+      return;
+   }
+   if ( dockAreaPopup->isVisible() ) {
+      dockAreaPopup->hide();
       return;
    }
 
@@ -299,7 +299,7 @@ void KMixDockWidget::activate(const QPoint &pos)
    dockAreaPopup->move(x, y);  // so that the mouse is outside of the widget
    kDebug() << "moving to" << dockAreaPopup->size() << x << y;
 
-   dockAreaPopup->setVisible(activated);
+   dockAreaPopup->show();
 
    // Now handle Multihead displays. And also make sure that the dialog is not
    // moved out-of-the screen on the right (see Bug 101742).
