@@ -13,11 +13,12 @@
 
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 #include "asynchttpsubmit.h"
+
 #include <kio/job.h>
 #include <kdebug.h>
 
@@ -33,17 +34,17 @@ namespace KCDDB
   {
 
   }
-  
-  CDDB::Result AsyncHTTPSubmit::runJob(KIO::Job* job)
-  {
-    connect(job, SIGNAL(result(KIO::Job *)), SLOT(slotFinished(KIO::Job *)));
 
-    return CDDB::Success;
-  }
-  
-  void AsyncHTTPSubmit::slotFinished(KIO::Job* job)
+  Result AsyncHTTPSubmit::runJob(KIO::Job* job)
   {
-    kdDebug() << "Finished" << endl;
+    connect(job, SIGNAL(result(KJob *)), SLOT(slotFinished(KJob *)));
+
+    return Success;
+  }
+
+  void AsyncHTTPSubmit::slotFinished(KJob* job)
+  {
+    kDebug() << "Finished";
 
     if ( job->error()==0 )
       emit finished( Success );
