@@ -13,12 +13,14 @@
 
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 #include "syncsmtpsubmit.h"
+
 #include "cdinfo.h"
+
 #include <kio/netaccess.h>
 #include <kio/job.h>
 
@@ -36,7 +38,7 @@ namespace KCDDB
 
   }
 
-  CDDB::Result SyncSMTPSubmit::runJob(KIO::Job* job)
+  Result SyncSMTPSubmit::runJob(KIO::Job* job)
   {
     if ( KIO::NetAccess::synchronousRun(job, 0) )
       return Success;
